@@ -493,7 +493,11 @@ AllocationStateType = Literal[
     "under-assessment",
 ]
 AllocationStrategyType = Literal[
-    "capacityOptimized", "capacityOptimizedPrioritized", "diversified", "lowestPrice"
+    "capacityOptimized",
+    "capacityOptimizedPrioritized",
+    "diversified",
+    "lowestPrice",
+    "priceCapacityOptimized",
 ]
 AllocationTypeType = Literal["used"]
 AllowsMultipleInstanceTypesType = Literal["off", "on"]
@@ -1784,7 +1788,11 @@ SnapshotAttributeNameType = Literal["createVolumePermission", "productCodes"]
 SnapshotCompletedWaiterName = Literal["snapshot_completed"]
 SnapshotStateType = Literal["completed", "error", "pending", "recoverable", "recovering"]
 SpotAllocationStrategyType = Literal[
-    "capacity-optimized", "capacity-optimized-prioritized", "diversified", "lowest-price"
+    "capacity-optimized",
+    "capacity-optimized-prioritized",
+    "diversified",
+    "lowest-price",
+    "price-capacity-optimized",
 ]
 SpotInstanceInterruptionBehaviorType = Literal["hibernate", "stop", "terminate"]
 SpotInstanceRequestFulfilledWaiterName = Literal["spot_instance_request_fulfilled"]
@@ -2209,6 +2217,7 @@ ServiceName = Literal[
     "sagemaker-featurestore-runtime",
     "sagemaker-runtime",
     "savingsplans",
+    "scheduler",
     "schemas",
     "sdb",
     "secretsmanager",
@@ -2447,6 +2456,7 @@ RegionName = Literal[
     "ap-southeast-3",
     "ca-central-1",
     "eu-central-1",
+    "eu-central-2",
     "eu-north-1",
     "eu-south-1",
     "eu-west-1",
